@@ -375,11 +375,13 @@ report_menugoal(struct event *event, struct rtas_priv_hdr_scn *privhdr,
 				break;
 			}
 
-			if (date != NULL)
+			if (date != NULL) {
 				offset += sprintf(buffer + offset, msg,
 						  asctime(date));
-			else
-				offset += sprintf(buffer + offset, "%s", msg);
+			} else {
+				if (msg) /* msg == NULL if epow->action_code > 7 */
+					offset += sprintf(buffer + offset, "%s", msg);
+			}
 		}
 
 		if (menu_num == 0) {
